@@ -1,3 +1,7 @@
+"""
+Source processing classes
+=========================
+"""
 import datetime
 import hashlib
 import json
@@ -12,12 +16,11 @@ from dateutil.parser import parse as parse_datetime
 from pymongo import TEXT, ASCENDING
 
 from .Config import Configuration
-from .JSONFileHandler import JSONFileHandler
 from .Toolkit import generate_title
-from .XMLFileHandler import XMLFileHandler
 from .content_handlers import CapecHandler, CWEHandler
 from .db_action import DatabaseAction
 from CveXplore.database.connection.mongo_db import MongoDBConnection
+from .file_handlers import XMLFileHandler, JSONFileHandler
 
 file_prefix = "nvdcve-1.1-"
 file_suffix = ".json.gz"
@@ -34,6 +37,10 @@ cveStartYear = Configuration.getCVEStartYear()
 
 
 class CPEDownloads(JSONFileHandler):
+    """
+    Class processing CPE source files
+    """
+
     def __init__(self):
         self.feed_type = "CPE"
         self.prefix = "matches.item"
@@ -135,6 +142,10 @@ class CPEDownloads(JSONFileHandler):
 
 
 class CVEDownloads(JSONFileHandler):
+    """
+    Class processing CVE source files
+    """
+
     def __init__(self):
         self.feed_type = "CVES"
         self.prefix = "CVE_Items.item"
@@ -637,6 +648,10 @@ class CVEDownloads(JSONFileHandler):
 
 
 class VIADownloads(JSONFileHandler):
+    """
+    Class processing VIA4 source files
+    """
+
     def __init__(self):
         self.feed_type = "VIA4"
         self.prefix = "cves"
@@ -720,6 +735,10 @@ class VIADownloads(JSONFileHandler):
 
 
 class CAPECDownloads(XMLFileHandler):
+    """
+    Class processing CAPEC source files
+    """
+
     def __init__(self):
         self.feed_type = "CAPEC"
         super().__init__(self.feed_type)
@@ -778,6 +797,10 @@ class CAPECDownloads(XMLFileHandler):
 
 
 class CWEDownloads(XMLFileHandler):
+    """
+    Class processing CWE source files
+    """
+
     def __init__(self):
         self.feed_type = "CWE"
         super().__init__(self.feed_type)
@@ -844,6 +867,10 @@ MongoAddIndex = namedtuple("MongoAddIndex", "index name")
 
 
 class DatabaseIndexer(object):
+    """
+    Class processing the Mongodb indexes
+    """
+
     def __init__(self):
 
         database = MongoDBConnection(**json.loads(os.getenv("MONGODB_CON_DETAILS")))
@@ -851,25 +878,12 @@ class DatabaseIndexer(object):
 
         self.indexes = {
             "cpe": [
-                MongoUniqueIndex(
-                    index=[("id", ASCENDING)],
-                    name="id",
-                    unique=True,
-                ),
-                MongoAddIndex(
-                    index=[("vendor", ASCENDING)], name="vendor"
-                ),
-                MongoAddIndex(
-                    index=[("product", ASCENDING)],
-                    name="product",
-                ),
+                MongoUniqueIndex(index=[("id", ASCENDING)], name="id", unique=True),
+                MongoAddIndex(index=[("vendor", ASCENDING)], name="vendor"),
+                MongoAddIndex(index=[("product", ASCENDING)], name="product"),
             ],
             "cpeother": [
-                MongoUniqueIndex(
-                    index=[("id", ASCENDING)],
-                    name="id",
-                    unique=True,
-                )
+                MongoUniqueIndex(index=[("id", ASCENDING)], name="id", unique=True)
             ],
             "cves": [
                 MongoAddIndex(index=[("id", ASCENDING)], name="id"),
@@ -878,38 +892,18 @@ class DatabaseIndexer(object):
                     name="vulnerable_configuration",
                 ),
                 MongoAddIndex(
-                    index=[("vulnerable_product", ASCENDING)],
-                    name="vulnerable_product",
+                    index=[("vulnerable_product", ASCENDING)], name="vulnerable_product"
                 ),
+                MongoAddIndex(index=[("Modified", ASCENDING)], name="Modified"),
+                MongoAddIndex(index=[("Published", ASCENDING)], name="Published"),
                 MongoAddIndex(
-                    index=[("Modified", ASCENDING)],
-                    name="Modified",
-                ),
-                MongoAddIndex(
-                    index=[("Published", ASCENDING)],
-                    name="Published",
-                ),
-                MongoAddIndex(
-                    index=[("last-modified", ASCENDING)],
-                    name="last-modified",
-                ),
-                MongoAddIndex(
-                    index=[("cvss", ASCENDING)], name="cvss"
-                ),
-                MongoAddIndex(
-                    index=[("cvss3", ASCENDING)], name="cvss3"
-                ),
-                MongoAddIndex(
-                    index=[("summary", TEXT)], name="summary"
-                ),
-                MongoAddIndex(
-                    index=[("vendors", ASCENDING)],
-                    name="vendors",
-                ),
-                MongoAddIndex(
-                    index=[("products", ASCENDING)],
-                    name="products",
+                    index=[("last-modified", ASCENDING)], name="last-modified"
                 ),
+                MongoAddIndex(index=[("cvss", ASCENDING)], name="cvss"),
+                MongoAddIndex(index=[("cvss3", ASCENDING)], name="cvss3"),
+                MongoAddIndex(index=[("summary", TEXT)], name="summary"),
+                MongoAddIndex(index=[("vendors", ASCENDING)], name="vendors"),
+                MongoAddIndex(index=[("products", ASCENDING)], name="products"),
                 MongoAddIndex(
                     index=[("vulnerable_product_stems", ASCENDING)],
                     name="vulnerable_product_stems",
@@ -919,19 +913,12 @@ class DatabaseIndexer(object):
                     name="vulnerable_configuration_stems",
                 ),
             ],
-            "via4": [
-                MongoAddIndex(index=[("id", ASCENDING)], name="id")
-            ],
-            "mgmt_whitelist": [
-                MongoAddIndex(index=[("id", ASCENDING)], name="id")
-            ],
-            "mgmt_blacklist": [
-                MongoAddIndex(index=[("id", ASCENDING)], name="id")
-            ],
+            "via4": [MongoAddIndex(index=[("id", ASCENDING)], name="id")],
+            "mgmt_whitelist": [MongoAddIndex(index=[("id", ASCENDING)], name="id")],
+            "mgmt_blacklist": [MongoAddIndex(index=[("id", ASCENDING)], name="id")],
             "capec": [
                 MongoAddIndex(
-                    index=[("related_weakness", ASCENDING)],
-                    name="related_weakness",
+                    index=[("related_weakness", ASCENDING)], name="related_weakness"
                 )
             ],
         }
@@ -958,15 +945,10 @@ class DatabaseIndexer(object):
                 for each in self.indexes[collection]:
                     if isinstance(each, MongoUniqueIndex):
                         self.setIndex(
-                            collection,
-                            each.index,
-                            name=each.name,
-                            unique=each.unique,
+                            collection, each.index, name=each.name, unique=each.unique
                         )
                     elif isinstance(each, MongoAddIndex):
-                        self.setIndex(
-                            collection, each.index, name=each.name
-                        )
+                        self.setIndex(collection, each.index, name=each.name)
             except KeyError:
                 # no specific index given, continue
                 self.logger.warning(
@@ -984,15 +966,10 @@ class DatabaseIndexer(object):
                 for each in self.indexes[collection]:
                     if isinstance(each, MongoUniqueIndex):
                         self.setIndex(
-                            collection,
-                            each.index,
-                            name=each.name,
-                            unique=each.unique,
+                            collection, each.index, name=each.name, unique=each.unique
                         )
                     elif isinstance(each, MongoAddIndex):
-                        self.setIndex(
-                            collection, each.index, name=each.name
-                        )
+                        self.setIndex(collection, each.index, name=each.name)
 
     def iter_indexes(self):
         for each in self.get_via4_indexes():
